export declare type Maybe<T> = T | null;
export declare type Exact<T extends {
    [key: string]: unknown;
}> = {
    [K in keyof T]: T[K];
};
export declare type MakeOptional<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]?: Maybe<T[SubKey]>;
};
export declare type MakeMaybe<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]: Maybe<T[SubKey]>;
};
/** All built-in and custom scalars, mapped to their actual values */
export declare type Scalars = {
    ID: string;
    String: string;
    Boolean: boolean;
    Int: number;
    Float: number;
    /**
     * The `GenericScalar` scalar type represents a generic
     * GraphQL scalar value that could be:
     * String, Boolean, Int, Float, List or Object.
     */
    GenericScalar: any;
    /** Wrapper around Graphene DateTime that is capable of handling string dates */
    DateTime: any;
    /**
     * The `Date` scalar type represents a Date
     * value as specified by
     * [iso8601](https://en.wikipedia.org/wiki/ISO_8601).
     */
    Date: any;
    /**
     * Limit is a GraphQL Scalar that can take in inf or positive integers.
     *
     * This class helps us normalize a API limit input into the Optional[int] type expected by library code
     */
    LimitInput: any;
};
/**
 * Base Query object exposed by GraphQL for the MQL Server
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type Query = {
    __typename?: 'Query';
    version?: Maybe<Scalars['String']>;
    boom?: Maybe<Scalars['Boolean']>;
    mqlQuery?: Maybe<MqlQuery>;
    sourceQuery?: Maybe<Scalars['String']>;
    materializations?: Maybe<Array<Materialization>>;
    metrics?: Maybe<Array<Metric>>;
    metricByName?: Maybe<Metric>;
    measures?: Maybe<Array<Measure>>;
    measureByName?: Maybe<Measure>;
    dimensionNamesForMetrics?: Maybe<Array<Maybe<Scalars['String']>>>;
    dimensionNamesForMetricsMultihop?: Maybe<Array<Maybe<Scalars['String']>>>;
    dimensionsForMetrics?: Maybe<Dimensions>;
    primaryTimeDimension?: Maybe<Dimension>;
    queries?: Maybe<Array<Maybe<MqlQuery>>>;
    healthReport?: Maybe<Array<Maybe<MqlServerHealthItem>>>;
};
/**
 * Base Query object exposed by GraphQL for the MQL Server
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type QueryBoomArgs = {
    raise_?: Maybe<Scalars['Boolean']>;
};
/**
 * Base Query object exposed by GraphQL for the MQL Server
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type QueryMqlQueryArgs = {
    id: Scalars['ID'];
};
/**
 * Base Query object exposed by GraphQL for the MQL Server
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type QuerySourceQueryArgs = {
    id: Scalars['ID'];
};
/**
 * Base Query object exposed by GraphQL for the MQL Server
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type QueryMaterializationsArgs = {
    modelKey?: Maybe<ModelKeyInput>;
};
/**
 * Base Query object exposed by GraphQL for the MQL Server
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type QueryMetricsArgs = {
    modelKey?: Maybe<ModelKeyInput>;
};
/**
 * Base Query object exposed by GraphQL for the MQL Server
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type QueryMetricByNameArgs = {
    modelKey?: Maybe<ModelKeyInput>;
    name: Scalars['String'];
};
/**
 * Base Query object exposed by GraphQL for the MQL Server
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type QueryMeasuresArgs = {
    modelKey?: Maybe<ModelKeyInput>;
};
/**
 * Base Query object exposed by GraphQL for the MQL Server
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type QueryMeasureByNameArgs = {
    modelKey?: Maybe<ModelKeyInput>;
    name: Scalars['String'];
};
/**
 * Base Query object exposed by GraphQL for the MQL Server
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type QueryDimensionNamesForMetricsArgs = {
    modelKey?: Maybe<ModelKeyInput>;
    metricNames?: Maybe<Array<Maybe<Scalars['String']>>>;
};
/**
 * Base Query object exposed by GraphQL for the MQL Server
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type QueryDimensionNamesForMetricsMultihopArgs = {
    modelKey?: Maybe<ModelKeyInput>;
    metricNames?: Maybe<Array<Maybe<Scalars['String']>>>;
};
/**
 * Base Query object exposed by GraphQL for the MQL Server
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type QueryDimensionsForMetricsArgs = {
    modelKey?: Maybe<ModelKeyInput>;
    metricNames?: Maybe<Array<Maybe<Scalars['String']>>>;
};
/**
 * Base Query object exposed by GraphQL for the MQL Server
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type QueryPrimaryTimeDimensionArgs = {
    modelKey?: Maybe<ModelKeyInput>;
};
/**
 * Base Query object exposed by GraphQL for the MQL Server
 *
 * Each field defined below is accessible by the API, by calling the equivalent resolver.
 */
export declare type QueryQueriesArgs = {
    activeOnly?: Maybe<Scalars['Boolean']>;
    status?: Maybe<MqlQueryStatus>;
    metricNames?: Maybe<Array<Maybe<Scalars['String']>>>;
    dateRangeStart?: Maybe<Scalars['Date']>;
    dateRangeEnd?: Maybe<Scalars['Date']>;
    minExecutionSeconds?: Maybe<Scalars['Float']>;
    maxExecutionSeconds?: Maybe<Scalars['Float']>;
    userIds?: Maybe<Array<Maybe<Scalars['Int']>>>;
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
};
/**
 * The MQL Query class is used to access the output of an MQL Query.
 *
 * Since queries are processed asynchronously, the status field indicates whether results are available.
 * Once complete, the results are available either in a strongly typed format, `result`, or
 * a generic, tabular format suitable for constructing a Pandas DataFrame.
 */
export declare type MqlQuery = {
    __typename?: 'MqlQuery';
    /** Query IDs are disposable, as query results expire in a short period of time. It is expected that queries are created, and then results are retrieved immediately upon query completion. */
    id?: Maybe<Scalars['ID']>;
    /** The model key used when creating the query */
    modelKey?: Maybe<ModelKey>;
    /** ID of the user who executed the query */
    userId?: Maybe<Scalars['Int']>;
    metrics?: Maybe<Array<Scalars['String']>>;
    dimensions?: Maybe<Array<Scalars['String']>>;
    /** The status of the requested query */
    status?: Maybe<MqlQueryStatus>;
    result?: Maybe<Array<MqlQueryResultSeries>>;
    /** The Tabular Results are Base 64-encoded JSON of a subset of rows from the query results Data Frame. */
    resultTabular?: Maybe<MqlQueryTabularResult>;
    /** The completion time for the query result. If using the MQL result cache, helps check when the latest cache fill occurred. */
    completedAt?: Maybe<Scalars['DateTime']>;
    resultTableSchema?: Maybe<Scalars['String']>;
    resultTableName?: Maybe<Scalars['String']>;
    resultSource?: Maybe<QueryResultSource>;
    resultPrimaryTimeGranularity?: Maybe<TimeGranularity>;
    /** Time this query was submitted to the MQL server */
    createdAt?: Maybe<Scalars['DateTime']>;
    /** Time the MQL Server start query execution */
    startedAt?: Maybe<Scalars['DateTime']>;
    sql?: Maybe<Scalars['String']>;
    error?: Maybe<Scalars['String']>;
    errorTraceback?: Maybe<Scalars['String']>;
    userFriendlyErrorType?: Maybe<MqlQueryUserFriendlyErrorType>;
    logs?: Maybe<Scalars['String']>;
    logsByLine?: Maybe<Scalars['String']>;
    chartValueMin?: Maybe<Scalars['Float']>;
    chartValueMax?: Maybe<Scalars['Float']>;
};
/**
 * The MQL Query class is used to access the output of an MQL Query.
 *
 * Since queries are processed asynchronously, the status field indicates whether results are available.
 * Once complete, the results are available either in a strongly typed format, `result`, or
 * a generic, tabular format suitable for constructing a Pandas DataFrame.
 */
export declare type MqlQueryResultTabularArgs = {
    cursor?: Maybe<Scalars['Int']>;
    orient?: Maybe<PandasJsonOrient>;
};
/**
 * The MQL Query class is used to access the output of an MQL Query.
 *
 * Since queries are processed asynchronously, the status field indicates whether results are available.
 * Once complete, the results are available either in a strongly typed format, `result`, or
 * a generic, tabular format suitable for constructing a Pandas DataFrame.
 */
export declare type MqlQueryLogsByLineArgs = {
    fromLine?: Maybe<Scalars['Int']>;
    maxLines?: Maybe<Scalars['Int']>;
};
/** API Output definition for a Model Key */
export declare type ModelKey = {
    __typename?: 'ModelKey';
    organization: Scalars['String'];
    repo: Scalars['String'];
    branch: Scalars['String'];
    commit: Scalars['String'];
};
/**
 * The status of queries submitted for execution in the query manager.
 *
 * Note: Obviously we need to link this from the version in query_manager.
 */
export declare enum MqlQueryStatus {
    Pending = "PENDING",
    Running = "RUNNING",
    Successful = "SUCCESSFUL",
    Failed = "FAILED",
    UnhandledException = "UNHANDLED_EXCEPTION",
    Unknown = "UNKNOWN"
}
/** This is the canonical shape for chart-ready data. */
export declare type MqlQueryResultSeries = {
    __typename?: 'MqlQueryResultSeries';
    /** For queries without dimensional cuts, series_value will be `ALL`. For queries with dimensional cuts, one of these Result will be returned per dimension */
    seriesValue?: Maybe<Scalars['String']>;
    data?: Maybe<Array<ResultDatum>>;
};
/** This interface is used to describe any type of MQL Query result data */
export declare type ResultDatum = {
    y?: Maybe<Scalars['GenericScalar']>;
};
/** Object type for Tabular data used to populate Pandas DataFrames */
export declare type MqlQueryTabularResult = {
    __typename?: 'MqlQueryTabularResult';
    /** Base-64 encoded Pandas DataFrame dumped to JSON using the specified orient. */
    data?: Maybe<Scalars['String']>;
    /** If present, the cursor indicates the value to pass for the next batch of records. If null, all results have been transferred. */
    nextCursor?: Maybe<Scalars['String']>;
};
/**
 * Determines the format of the JSON output for the DataFrame
 *
 * See https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.to_json.html
 */
export declare enum PandasJsonOrient {
    Split = "SPLIT",
    Records = "RECORDS",
    Index = "INDEX",
    Columns = "COLUMNS",
    Values = "VALUES",
    Table = "TABLE"
}
/** Different ways that a query result could have been computed or retrieved. */
export declare enum QueryResultSource {
    DynamicCache = "DYNAMIC_CACHE",
    DwMaterialization = "DW_MATERIALIZATION",
    FastCache = "FAST_CACHE",
    NotApplicable = "NOT_APPLICABLE",
    NotSpecified = "NOT_SPECIFIED"
}
/**
 * For time dimensions, the smallest possible difference between two time values.
 *
 *     Needed for calculating adjacency when merging 2 different time ranges.
 */
export declare enum TimeGranularity {
    Day = "DAY",
    Week = "WEEK",
    Month = "MONTH",
    Quarter = "QUARTER",
    Year = "YEAR"
}
/** User friendly error types to return with MqlQuery */
export declare enum MqlQueryUserFriendlyErrorType {
    DbError = "DB_ERROR",
    UnableToSatisfyQueryError = "UNABLE_TO_SATISFY_QUERY_ERROR",
    Unknown = "UNKNOWN"
}
export declare type Materialization = {
    __typename?: 'Materialization';
    name: Scalars['String'];
    metrics?: Maybe<Array<Scalars['String']>>;
    dimensions?: Maybe<Array<Scalars['String']>>;
    destinationTable?: Maybe<Scalars['String']>;
};
/** API Input definition for a Model Key */
export declare type ModelKeyInput = {
    organization: Scalars['String'];
    repo: Scalars['String'];
    branch: Scalars['String'];
    commit: Scalars['String'];
};
export declare type Metric = {
    __typename?: 'Metric';
    name: Scalars['String'];
    measures?: Maybe<Array<Scalars['String']>>;
    dimensions?: Maybe<Array<Scalars['String']>>;
    dimensionValues?: Maybe<Array<Maybe<Scalars['String']>>>;
};
export declare type MetricDimensionValuesArgs = {
    modelKey?: Maybe<ModelKeyInput>;
    dimensionName?: Maybe<Scalars['String']>;
    startTime?: Maybe<Scalars['String']>;
    endTime?: Maybe<Scalars['String']>;
};
export declare type Measure = {
    __typename?: 'Measure';
    name: Scalars['String'];
    dataSources?: Maybe<Array<Scalars['String']>>;
};
export declare type Dimensions = {
    __typename?: 'Dimensions';
    localDimensions?: Maybe<Array<Maybe<Dimension>>>;
    nonLocalDimensions?: Maybe<Array<Maybe<Dimension>>>;
};
export declare type DimensionsLocalDimensionsArgs = {
    modelKey?: Maybe<ModelKeyInput>;
    metricNames?: Maybe<Array<Maybe<Scalars['String']>>>;
};
export declare type DimensionsNonLocalDimensionsArgs = {
    modelKey?: Maybe<ModelKeyInput>;
    metricNames?: Maybe<Array<Maybe<Scalars['String']>>>;
};
export declare type Dimension = {
    __typename?: 'Dimension';
    name: Scalars['String'];
    identifierName?: Maybe<Scalars['String']>;
    type?: Maybe<DimensionType>;
    isPrimaryTime?: Maybe<Scalars['Boolean']>;
    values?: Maybe<Array<Scalars['String']>>;
    cardinality?: Maybe<Scalars['Int']>;
};
/** Determines types values expected of dimension */
export declare enum DimensionType {
    Categorical = "CATEGORICAL",
    Time = "TIME"
}
export declare type MqlServerHealthItem = {
    __typename?: 'MqlServerHealthItem';
    name: Scalars['String'];
    status: Scalars['String'];
    errorMessage?: Maybe<Scalars['String']>;
};
/** Base mutation object exposed by GraphQL. */
export declare type Mutation = {
    __typename?: 'Mutation';
    createMqlMaterializationNew?: Maybe<CreateMqlMaterializationNewPayload>;
    createMqlDropMaterialization?: Maybe<CreateMqlDropMaterializationPayload>;
    /**
     * This mutation is used to initiate an MQL Query.
     *
     * The primary return value is a queryId that can be used to fetch the query status, errors, and results.
     * The full query object is also returned in case we have a result available synchronously (stored the result cache)
     */
    createMqlQuery?: Maybe<CreateMqlQueryPayload>;
    /** @deprecated Moving to async implementation (CreateMqlMaterializationNew) */
    materialize?: Maybe<Materialize>;
    /** Drop the MQL dynamic cache. Please avoid doing this unless there's a cache corruption issue. */
    dropCache?: Maybe<DropCache>;
    /** Stores hosted MQL Server config using AWS Secrets Manager. */
    updateMqlServerConfig?: Maybe<UpdateMqlServerConfig>;
    /** Removes hosted MQL Server config using AWS Secrets Manager. */
    revokeMqlServerConfig?: Maybe<RevokeMqlServerConfig>;
    /** Rewrites SQL containing an MQL(...) function invocation by expanding into generated SQL */
    rewriteMqlSql?: Maybe<RewriteMqlSql>;
};
/** Base mutation object exposed by GraphQL. */
export declare type MutationCreateMqlMaterializationNewArgs = {
    input: CreateMqlMaterializationNewInput;
};
/** Base mutation object exposed by GraphQL. */
export declare type MutationCreateMqlDropMaterializationArgs = {
    input: CreateMqlDropMaterializationInput;
};
/** Base mutation object exposed by GraphQL. */
export declare type MutationCreateMqlQueryArgs = {
    input: CreateMqlQueryInput;
};
/** Base mutation object exposed by GraphQL. */
export declare type MutationMaterializeArgs = {
    asTable?: Maybe<Scalars['String']>;
    cacheMode?: Maybe<CacheMode>;
    groupBy?: Maybe<Array<Scalars['String']>>;
    metrics?: Maybe<Array<Scalars['String']>>;
    modelKey?: Maybe<ModelKeyInput>;
    where?: Maybe<Scalars['String']>;
};
/** Base mutation object exposed by GraphQL. */
export declare type MutationDropCacheArgs = {
    confirm?: Maybe<Scalars['String']>;
};
/** Base mutation object exposed by GraphQL. */
export declare type MutationUpdateMqlServerConfigArgs = {
    dwPassword?: Maybe<Scalars['String']>;
    modeCreds?: Maybe<Scalars['String']>;
    mqlServerId?: Maybe<Scalars['Int']>;
    tfdApiKey?: Maybe<Scalars['String']>;
};
/** Base mutation object exposed by GraphQL. */
export declare type MutationRevokeMqlServerConfigArgs = {
    mqlServerId?: Maybe<Scalars['Int']>;
};
/** Base mutation object exposed by GraphQL. */
export declare type MutationRewriteMqlSqlArgs = {
    sql: Scalars['String'];
};
export declare type CreateMqlMaterializationNewPayload = {
    __typename?: 'CreateMqlMaterializationNewPayload';
    id?: Maybe<Scalars['ID']>;
    clientMutationId?: Maybe<Scalars['String']>;
};
export declare type CreateMqlMaterializationNewInput = {
    modelKey?: Maybe<ModelKeyInput>;
    materializationName?: Maybe<Scalars['String']>;
    startTime?: Maybe<Scalars['String']>;
    endTime?: Maybe<Scalars['String']>;
    outputTable?: Maybe<Scalars['String']>;
    clientMutationId?: Maybe<Scalars['String']>;
};
export declare type CreateMqlDropMaterializationPayload = {
    __typename?: 'CreateMqlDropMaterializationPayload';
    id?: Maybe<Scalars['ID']>;
    clientMutationId?: Maybe<Scalars['String']>;
};
export declare type CreateMqlDropMaterializationInput = {
    modelKey?: Maybe<ModelKeyInput>;
    materializationName?: Maybe<Scalars['String']>;
    startTime?: Maybe<Scalars['String']>;
    endTime?: Maybe<Scalars['String']>;
    clientMutationId?: Maybe<Scalars['String']>;
};
/**
 * This mutation is used to initiate an MQL Query.
 *
 * The primary return value is a queryId that can be used to fetch the query status, errors, and results.
 * The full query object is also returned in case we have a result available synchronously (stored the result cache)
 */
export declare type CreateMqlQueryPayload = {
    __typename?: 'CreateMqlQueryPayload';
    id: Scalars['ID'];
    query?: Maybe<MqlQuery>;
    clientMutationId?: Maybe<Scalars['String']>;
};
export declare type CreateMqlQueryInput = {
    modelKey?: Maybe<ModelKeyInput>;
    metrics?: Maybe<Array<Scalars['String']>>;
    groupBy?: Maybe<Array<Scalars['String']>>;
    where?: Maybe<ConstraintInput>;
    whereConstraint?: Maybe<Scalars['String']>;
    timeConstraint?: Maybe<Scalars['String']>;
    /** Optionally, provide a granularity for the primary time dimension in the returned results. */
    timeGranularity?: Maybe<TimeGranularity>;
    order?: Maybe<Array<Scalars['String']>>;
    /** Integer, '-1', or 'inf' to represent the number of rows of a query to return input field */
    limit?: Maybe<Scalars['LimitInput']>;
    /** Set to True if you want to automatically add a default Time Series dimension to the query. This is useful for plotting the metric in time series without needing to know the time dimension up front. */
    addTimeSeries?: Maybe<Scalars['Boolean']>;
    /** Optionally, provide a cache mode to instruct the query engine how/whether to check the cache for data. */
    cacheMode?: Maybe<CacheMode>;
    useResultCache?: Maybe<Scalars['Boolean']>;
    resultFormat?: Maybe<ResultFormat>;
    asTable?: Maybe<Scalars['String']>;
    /** Aggregate results by selected time period. */
    granularity?: Maybe<Granularity>;
    /** Calculate percentage changed from current time period to previous time period. Must also select granularity. */
    pctChange?: Maybe<PercentChange>;
    startTime?: Maybe<Scalars['String']>;
    endTime?: Maybe<Scalars['String']>;
    /** If granularity is applied, trim start/end periods with incomplete date ranges or data. */
    trimIncompletePeriods?: Maybe<Scalars['Boolean']>;
    /** Limit time dimension to a specific number of days, whether or not those days have data. */
    daysLimit?: Maybe<Scalars['Int']>;
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Container class for inputs to allow for and/or wrappers on the `where` clause */
export declare type ConstraintInput = {
    And?: Maybe<Array<SingleConstraintInput>>;
    constraint?: Maybe<SingleConstraintInput>;
};
/** Actual `where` clauses to be applied */
export declare type SingleConstraintInput = {
    constraintType?: Maybe<AtomicConstraintType>;
    dimensionName?: Maybe<Scalars['String']>;
    values?: Maybe<Array<Maybe<Scalars['String']>>>;
    start?: Maybe<Scalars['String']>;
    stop?: Maybe<Scalars['String']>;
};
/** Current possible values for constraints */
export declare enum AtomicConstraintType {
    Set = "SET",
    Range = "RANGE"
}
/**
 * Options for the SemanticLayer cache.
 *
 *     Tables in a specified schema in the same data warehouse contain measure / dimension combinations that can be used to
 *     speed up queries for different measure / dimension combinations.
 */
export declare enum CacheMode {
    Read = "READ",
    Readwrite = "READWRITE",
    Write = "WRITE",
    Ignore = "IGNORE"
}
/** An enumeration. */
export declare enum ResultFormat {
    Tfd = "TFD"
}
/** An enumeration. */
export declare enum Granularity {
    Daily = "DAILY",
    Weekly = "WEEKLY",
    Monthly = "MONTHLY",
    Yearly = "YEARLY"
}
/** An enumeration. */
export declare enum PercentChange {
    Wow = "WOW",
    Mom = "MOM",
    Qoq = "QOQ",
    Yoy = "YOY"
}
export declare type Materialize = {
    __typename?: 'Materialize';
    schema?: Maybe<Scalars['String']>;
    table?: Maybe<Scalars['String']>;
};
/** Drop the MQL dynamic cache. Please avoid doing this unless there's a cache corruption issue. */
export declare type DropCache = {
    __typename?: 'DropCache';
    success?: Maybe<Scalars['Boolean']>;
};
/** Stores hosted MQL Server config using AWS Secrets Manager. */
export declare type UpdateMqlServerConfig = {
    __typename?: 'UpdateMqlServerConfig';
    config?: Maybe<MqlServerConfig>;
};
/** MQL Server configuration for hosted MQL Servers */
export declare type MqlServerConfig = {
    __typename?: 'MqlServerConfig';
    /** MQL Server ID as stored in the Backend */
    mqlServerId?: Maybe<Scalars['Int']>;
    /** Transform Data API Key. _Note:_ Stored securely using AWS Secrets Manager. */
    tfdApiKey?: Maybe<Scalars['String']>;
    /** Password used to access the Data Warehouse. _Note:_ Stored securely using AWS Secrets Manager. */
    dwPassword?: Maybe<Scalars['String']>;
    /** Mode bridge connection config. _Note:_ Stored securely using AWS Secrets Manager. */
    modeCreds?: Maybe<Scalars['String']>;
};
/** Removes hosted MQL Server config using AWS Secrets Manager. */
export declare type RevokeMqlServerConfig = {
    __typename?: 'RevokeMqlServerConfig';
    success?: Maybe<Scalars['Boolean']>;
};
/** Rewrites SQL containing an MQL(...) function invocation by expanding into generated SQL */
export declare type RewriteMqlSql = {
    __typename?: 'RewriteMqlSql';
    resultSql?: Maybe<Scalars['String']>;
};
/** MQL Query Result Data are expected to be plotted on a time series so this is the most common result type */
export declare type TimeSeriesDatum = ResultDatum & {
    __typename?: 'TimeSeriesDatum';
    y?: Maybe<Scalars['GenericScalar']>;
    xDate: Scalars['DateTime'];
};
export declare type CreateMqlQueryMutationVariables = Exact<{
    modelKey?: Maybe<ModelKeyInput>;
    metrics?: Maybe<Array<Scalars['String']> | Scalars['String']>;
    groupBy?: Maybe<Array<Scalars['String']> | Scalars['String']>;
    where?: Maybe<ConstraintInput>;
    addTimeSeries?: Maybe<Scalars['Boolean']>;
    pctChange?: Maybe<PercentChange>;
    timeGranularity?: Maybe<TimeGranularity>;
    granularity?: Maybe<Granularity>;
    startTime?: Maybe<Scalars['String']>;
    endTime?: Maybe<Scalars['String']>;
    limit?: Maybe<Scalars['LimitInput']>;
    order?: Maybe<Array<Scalars['String']> | Scalars['String']>;
    daysLimit?: Maybe<Scalars['Int']>;
}>;
export declare type CreateMqlQueryMutation = ({
    __typename?: 'Mutation';
} & {
    createMqlQuery?: Maybe<({
        __typename?: 'CreateMqlQueryPayload';
    } & Pick<CreateMqlQueryPayload, 'id'> & {
        query?: Maybe<({
            __typename?: 'MqlQuery';
        } & Pick<MqlQuery, 'id' | 'status' | 'metrics' | 'dimensions' | 'error'> & {
            result?: Maybe<Array<({
                __typename?: 'MqlQueryResultSeries';
            } & Pick<MqlQueryResultSeries, 'seriesValue'> & {
                data?: Maybe<Array<({
                    __typename?: 'TimeSeriesDatum';
                } & Pick<TimeSeriesDatum, 'xDate' | 'y'>)>>;
            })>>;
        })>;
    })>;
});
export declare type UpdateMqlServerConfigMutationVariables = Exact<{
    mqlServerId: Scalars['Int'];
    dwPassword?: Maybe<Scalars['String']>;
    modeCreds?: Maybe<Scalars['String']>;
    tfdApiKey: Scalars['String'];
}>;
export declare type UpdateMqlServerConfigMutation = ({
    __typename?: 'Mutation';
} & {
    updateMqlServerConfig?: Maybe<({
        __typename?: 'UpdateMqlServerConfig';
    } & {
        config?: Maybe<({
            __typename?: 'MqlServerConfig';
        } & Pick<MqlServerConfig, 'mqlServerId' | 'modeCreds'>)>;
    })>;
});
