"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PercentChange = exports.Granularity = exports.ResultFormat = exports.CacheMode = exports.AtomicConstraintType = exports.DimensionType = exports.MqlQueryUserFriendlyErrorType = exports.TimeGranularity = exports.QueryResultSource = exports.PandasJsonOrient = exports.MqlQueryStatus = void 0;
/**
 * The status of queries submitted for execution in the query manager.
 *
 * Note: Obviously we need to link this from the version in query_manager.
 */
var MqlQueryStatus;
(function (MqlQueryStatus) {
    MqlQueryStatus["Pending"] = "PENDING";
    MqlQueryStatus["Running"] = "RUNNING";
    MqlQueryStatus["Successful"] = "SUCCESSFUL";
    MqlQueryStatus["Failed"] = "FAILED";
    MqlQueryStatus["UnhandledException"] = "UNHANDLED_EXCEPTION";
    MqlQueryStatus["Unknown"] = "UNKNOWN";
})(MqlQueryStatus = exports.MqlQueryStatus || (exports.MqlQueryStatus = {}));
/**
 * Determines the format of the JSON output for the DataFrame
 *
 * See https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.to_json.html
 */
var PandasJsonOrient;
(function (PandasJsonOrient) {
    PandasJsonOrient["Split"] = "SPLIT";
    PandasJsonOrient["Records"] = "RECORDS";
    PandasJsonOrient["Index"] = "INDEX";
    PandasJsonOrient["Columns"] = "COLUMNS";
    PandasJsonOrient["Values"] = "VALUES";
    PandasJsonOrient["Table"] = "TABLE";
})(PandasJsonOrient = exports.PandasJsonOrient || (exports.PandasJsonOrient = {}));
/** Different ways that a query result could have been computed or retrieved. */
var QueryResultSource;
(function (QueryResultSource) {
    QueryResultSource["DynamicCache"] = "DYNAMIC_CACHE";
    QueryResultSource["DwMaterialization"] = "DW_MATERIALIZATION";
    QueryResultSource["FastCache"] = "FAST_CACHE";
    QueryResultSource["NotApplicable"] = "NOT_APPLICABLE";
    QueryResultSource["NotSpecified"] = "NOT_SPECIFIED";
})(QueryResultSource = exports.QueryResultSource || (exports.QueryResultSource = {}));
/**
 * For time dimensions, the smallest possible difference between two time values.
 *
 *     Needed for calculating adjacency when merging 2 different time ranges.
 */
var TimeGranularity;
(function (TimeGranularity) {
    TimeGranularity["Day"] = "DAY";
    TimeGranularity["Week"] = "WEEK";
    TimeGranularity["Month"] = "MONTH";
    TimeGranularity["Quarter"] = "QUARTER";
    TimeGranularity["Year"] = "YEAR";
})(TimeGranularity = exports.TimeGranularity || (exports.TimeGranularity = {}));
/** User friendly error types to return with MqlQuery */
var MqlQueryUserFriendlyErrorType;
(function (MqlQueryUserFriendlyErrorType) {
    MqlQueryUserFriendlyErrorType["DbError"] = "DB_ERROR";
    MqlQueryUserFriendlyErrorType["UnableToSatisfyQueryError"] = "UNABLE_TO_SATISFY_QUERY_ERROR";
    MqlQueryUserFriendlyErrorType["Unknown"] = "UNKNOWN";
})(MqlQueryUserFriendlyErrorType = exports.MqlQueryUserFriendlyErrorType || (exports.MqlQueryUserFriendlyErrorType = {}));
/** Determines types values expected of dimension */
var DimensionType;
(function (DimensionType) {
    DimensionType["Categorical"] = "CATEGORICAL";
    DimensionType["Time"] = "TIME";
})(DimensionType = exports.DimensionType || (exports.DimensionType = {}));
/** Current possible values for constraints */
var AtomicConstraintType;
(function (AtomicConstraintType) {
    AtomicConstraintType["Set"] = "SET";
    AtomicConstraintType["Range"] = "RANGE";
})(AtomicConstraintType = exports.AtomicConstraintType || (exports.AtomicConstraintType = {}));
/**
 * Options for the SemanticLayer cache.
 *
 *     Tables in a specified schema in the same data warehouse contain measure / dimension combinations that can be used to
 *     speed up queries for different measure / dimension combinations.
 */
var CacheMode;
(function (CacheMode) {
    CacheMode["Read"] = "READ";
    CacheMode["Readwrite"] = "READWRITE";
    CacheMode["Write"] = "WRITE";
    CacheMode["Ignore"] = "IGNORE";
})(CacheMode = exports.CacheMode || (exports.CacheMode = {}));
/** An enumeration. */
var ResultFormat;
(function (ResultFormat) {
    ResultFormat["Tfd"] = "TFD";
})(ResultFormat = exports.ResultFormat || (exports.ResultFormat = {}));
/** An enumeration. */
var Granularity;
(function (Granularity) {
    Granularity["Daily"] = "DAILY";
    Granularity["Weekly"] = "WEEKLY";
    Granularity["Monthly"] = "MONTHLY";
    Granularity["Yearly"] = "YEARLY";
})(Granularity = exports.Granularity || (exports.Granularity = {}));
/** An enumeration. */
var PercentChange;
(function (PercentChange) {
    PercentChange["Wow"] = "WOW";
    PercentChange["Mom"] = "MOM";
    PercentChange["Qoq"] = "QOQ";
    PercentChange["Yoy"] = "YOY";
})(PercentChange = exports.PercentChange || (exports.PercentChange = {}));
